# OEF connection

Connection to interact with an OEF node (https://fetchai.github.io/oef-sdk-python/user/introduction.html).

## Usage

Register/unregister services, perform searches using `fetchai/oef_search:0.8.0` protocol and send messages of any protocol to other agents connected to the same node.